@@ -1,7 +1,9 @@
 has_internet <- curl::has_internet ()
 
-is_cran <- identical (Sys.getenv ("_R_CHECK_CRAN_INCOMING_"), 'true')
-is_travis <-  identical (Sys.getenv('TRAVIS'), 'true')
+# test_all used to switch off tests on CRAN
+test_all <- (identical (Sys.getenv ("MPADGE_LOCAL"), "true") |
+             identical (Sys.getenv ("TRAVIS"), "true") |
+             identical (Sys.getenv ("APPVEYOR"), "True"))
 
 source ('../stub.R')
 
@@ -68,7 +70,7 @@ test_that ('make_query', {
     {
         # Test all `osmdata_..` functions by stubbing the results of
         # `overpass_query()`
-        if (is_cran | is_travis)
+        if (!test_all)
         {
             load ("../overpass_query_result.rda")
             stub (osmdata_xml, 'overpass_query', function (x, ...)
@@ -78,7 +80,7 @@ test_that ('make_query', {
         expect_true (is (doc, 'xml_document'))
         expect_silent (osmdata_xml (qry, file = 'junk.osm'))
 
-        if (is_cran | is_travis)
+        if (!test_all)
             stub (osmdata_sp, 'overpass_query', function (x, ...)
                   overpass_query_result)
         res <- osmdata_sp (qry)
@@ -94,7 +96,7 @@ test_that ('make_query', {
                   'osm_multipolygons')
         expect_named (res, expected = nms, ignore.order = FALSE)
 
-        if (is_cran | is_travis)
+        if (!test_all)
             stub (osmdata_sf, 'overpass_query', function (x, ...)
                   overpass_query_result)
         res <- osmdata_sf (qry)
